ActiveNode trait — nodes that drive graph processing.
ActiveNode trait — moved to rill-core::traits.
This module is kept empty for backward compatibility only.
ActiveNode trait — nodes that drive graph processing.
ActiveNode trait — moved to rill-core::traits.
This module is kept empty for backward compatibility only.