Node factory and registry for constructing nodes by type name.
Structs
- Node
Registry - A registry of named node constructors.
Enums
- Registry
Error - Errors that can occur during node construction via the registry.
Traits
- Node
Constructor - Factory trait for creating graph nodes by type name.