Module registry

Module registry 

Node factory and registry for constructing nodes by type name.

Structs

NodeRegistry
A registry of named node constructors.

Enums

RegistryError
Errors that can occur during node construction via the registry.

Traits

NodeConstructor
Factory trait for creating graph nodes by type name.